def get_llm_cls(platform_type, model_name, model_config):
    if platform_type == "qianfan":
        from promptulate.llms import QianFan

        if model_name == "":
            return QianFan(model_config=model_config)
        else:
            return QianFan(model=model_name, model_config=model_config)
    elif platform_type == "zhipu":
        from promptulate.llms import ZhiPu

        if model_name == "":
            return ZhiPu(model_config=model_config)
        else:
            return ZhiPu(model=model_name, model_config=model_config)
    elif platform_type == "custom_llm":
        from promptulate.llms import CustomLLM

        if model_name == "":
            return CustomLLM(model_config=model_config)
        else:
            return CustomLLM(model=model_name, model_config=model_config)
    else:
        raise ImportError("not found this platform")


class LLMFactory:
    @classmethod
    def build(cls, platform_type: str, model_name: str = None, model_config: {} = None):
        if model_config is None:
            model_config = {}
        model_name: str = model_name or ""
        return get_llm_cls(
            platform_type=platform_type,
            model_name=model_name,
            model_config=model_config,
        )



# Copyright (c) 2023 promptulate
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Copyright Owner: Zeeland
# GitHub Link: https://github.com/Undertone0809/
# Project Link: https://github.com/Undertone0809/promptulate
# Contact Email: zeeland@foxmail.com

from promptulate.utils.color_print import print_text
from promptulate.utils.logger import enable_log, logger
from promptulate.utils.openai_key_pool import export_openai_key_pool
from promptulate.utils.singleton import AbstractSingleton, Singleton
from promptulate.utils.string_template import StringTemplate

__all__ = ["logger", "enable_log", "export_openai_key_pool", "StringTemplate"]
